# PrintSession


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**created_dt** | **datetime** |  | 
**updated_dt** | **datetime** |  | [readonly] 
**octoprint_device** | **int** |  | 
**active** | **bool** |  | [optional] 
**session** | **str** |  | 
**filepos** | **int** |  | [optional] 
**print_progress** | **int** |  | [optional] 
**time_elapsed** | **int** |  | [optional] 
**time_remaining** | **int** |  | [optional] 
**user** | **int** |  | [readonly] 
**printer_profile** | **int** |  | [optional] 
**gcode_file** | **int** |  | [optional] 
**gcode_filename** | **str** |  | [optional] 
**octoprint_job** | **dict(str, object)** |  | [optional] 
**print_job_status** | [**OctoJobEvent**](OctoJobEvent.md) |  | [optional] 
**url** | **str** |  | [readonly] 
**datesegment** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


